@@ -8,8 +8,10 @@
 metaplus <- function(yi,sei,mods=NULL,random="normal",
       label=switch(random,"normal"="Random Normal","t-dist"="Random t-distribution", "mixture"="Random mixture"),
       plotci=FALSE,justfit=FALSE,slab=1:length(yi),
-      useAGQ=FALSE,quadpoints=21,notrials=20, cores = max(detectCores() %/% 2, 1), 
+      useAGQ = FALSE,quadpoints=21,notrials=20, cores = max(detectCores() %/% 2, 1), 
       data) {
+  if (!missing(useAGQ)) warning('useAGQ is deprecated as AGQ is no longer available')
+  if (!missing(quadpoints)) warning('quadpoints is deprecated as AGQ is no longer available')
   if (!(random %in% c("normal","t-dist","mixture"))) stop("Unknown random effect type")
   if ((random=="mixture") & (notrials<10)) stop("Must be at least 10 sets of random starting values for mixture models.")
   if (cores<1) stop("Cores must be positive.")
@@ -47,7 +49,7 @@ metaplus <- function(yi,sei,mods=NULL,random="normal",
   if (cores>1) loadNamespace("parallel")
   fit <- switch(random,
                 "normal"=profilenorm.metaplus(yi,sei,mods=mods,justfit=justfit,plotci=plotci,slab=slab),
-                "t-dist"=profilet.metaplus(yi,sei,mods=mods,justfit=justfit,plotci=plotci,slab=slab,useAGQ=useAGQ,quadpoints=quadpoints),
+                "t-dist"=profilet.metaplus(yi,sei,mods=mods,justfit=justfit,plotci=plotci,slab=slab,quadpoints=quadpoints),
                 "mixture"=profilemix.metaplus(yi,sei,mods=mods,justfit=justfit,plotci=plotci,slab=slab,notrials=notrials,cores=cores))
   fit$label <- label
   class(fit) <- "metaplus"
