@@ -393,7 +393,7 @@ mymle <- function(minuslogl,
       } else {
         tmphess <- try(solve(oout$hessian,silent=TRUE))
       }
-      if (class(tmphess)=="try-error") {
+      if (inherits(tmphess,"try-error")) {
         tvcov <- matrix(NA,length(coef),length(coef))
         warning("couldn't invert Hessian")
       } else tvcov <- tmphess
